==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeploymentStatusBuilder extends ClusterDeploymentStatusFluentImpl<ClusterDeploymentStatusBuilder> implements VisitableBuilder<ClusterDeploymentStatus,ClusterDeploymentStatusBuilder>{
  public ClusterDeploymentStatusBuilder() {
    this(false);
  }
  public ClusterDeploymentStatusBuilder(Boolean validationEnabled) {
    this(new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiURL(instance.getApiURL());
      fluent.withCertificateBundles(instance.getCertificateBundles());
      fluent.withCliImage(instance.getCliImage());
      fluent.withConditions(instance.getConditions());
      fluent.withInstallRestarts(instance.getInstallRestarts());
      fluent.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      fluent.withInstallVersion(instance.getInstallVersion());
      fluent.withInstalledTimestamp(instance.getInstalledTimestamp());
      fluent.withInstallerImage(instance.getInstallerImage());
      fluent.withPlatformStatus(instance.getPlatformStatus());
      fluent.withPowerState(instance.getPowerState());
      fluent.withProvisionRef(instance.getProvisionRef());
      fluent.withWebConsoleURL(instance.getWebConsoleURL());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance) {
    this(instance,false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiURL(instance.getApiURL());
      this.withCertificateBundles(instance.getCertificateBundles());
      this.withCliImage(instance.getCliImage());
      this.withConditions(instance.getConditions());
      this.withInstallRestarts(instance.getInstallRestarts());
      this.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      this.withInstallVersion(instance.getInstallVersion());
      this.withInstalledTimestamp(instance.getInstalledTimestamp());
      this.withInstallerImage(instance.getInstallerImage());
      this.withPlatformStatus(instance.getPlatformStatus());
      this.withPowerState(instance.getPowerState());
      this.withProvisionRef(instance.getProvisionRef());
      this.withWebConsoleURL(instance.getWebConsoleURL());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeploymentStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeploymentStatus build() {
    ClusterDeploymentStatus buildable = new ClusterDeploymentStatus(fluent.getApiURL(),fluent.getCertificateBundles(),fluent.getCliImage(),fluent.getConditions(),fluent.getInstallRestarts(),fluent.getInstallStartedTimestamp(),fluent.getInstallVersion(),fluent.getInstalledTimestamp(),fluent.getInstallerImage(),fluent.getPlatformStatus(),fluent.getPowerState(),fluent.getProvisionRef(),fluent.getWebConsoleURL());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeploymentStatusBuilder extends ClusterDeploymentStatusFluent<ClusterDeploymentStatusBuilder> implements VisitableBuilder<ClusterDeploymentStatus,ClusterDeploymentStatusBuilder>{
  public ClusterDeploymentStatusBuilder() {
    this(false);
  }
  public ClusterDeploymentStatusBuilder(Boolean validationEnabled) {
    this(new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterDeploymentStatus());

    if (instance != null) {
      fluent.withApiURL(instance.getApiURL());
      fluent.withCertificateBundles(instance.getCertificateBundles());
      fluent.withCliImage(instance.getCliImage());
      fluent.withConditions(instance.getConditions());
      fluent.withInstallRestarts(instance.getInstallRestarts());
      fluent.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      fluent.withInstallVersion(instance.getInstallVersion());
      fluent.withInstalledTimestamp(instance.getInstalledTimestamp());
      fluent.withInstallerImage(instance.getInstallerImage());
      fluent.withPlatformStatus(instance.getPlatformStatus());
      fluent.withPowerState(instance.getPowerState());
      fluent.withProvisionRef(instance.getProvisionRef());
      fluent.withWebConsoleURL(instance.getWebConsoleURL());
      fluent.withApiURL(instance.getApiURL());
      fluent.withCertificateBundles(instance.getCertificateBundles());
      fluent.withCliImage(instance.getCliImage());
      fluent.withConditions(instance.getConditions());
      fluent.withInstallRestarts(instance.getInstallRestarts());
      fluent.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      fluent.withInstallVersion(instance.getInstallVersion());
      fluent.withInstalledTimestamp(instance.getInstalledTimestamp());
      fluent.withInstallerImage(instance.getInstallerImage());
      fluent.withPlatformStatus(instance.getPlatformStatus());
      fluent.withPowerState(instance.getPowerState());
      fluent.withProvisionRef(instance.getProvisionRef());
      fluent.withWebConsoleURL(instance.getWebConsoleURL());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance) {
    this(instance,false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterDeploymentStatus());

    if (instance != null) {
      this.withApiURL(instance.getApiURL());
      this.withCertificateBundles(instance.getCertificateBundles());
      this.withCliImage(instance.getCliImage());
      this.withConditions(instance.getConditions());
      this.withInstallRestarts(instance.getInstallRestarts());
      this.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      this.withInstallVersion(instance.getInstallVersion());
      this.withInstalledTimestamp(instance.getInstalledTimestamp());
      this.withInstallerImage(instance.getInstallerImage());
      this.withPlatformStatus(instance.getPlatformStatus());
      this.withPowerState(instance.getPowerState());
      this.withProvisionRef(instance.getProvisionRef());
      this.withWebConsoleURL(instance.getWebConsoleURL());
      this.withApiURL(instance.getApiURL());
      this.withCertificateBundles(instance.getCertificateBundles());
      this.withCliImage(instance.getCliImage());
      this.withConditions(instance.getConditions());
      this.withInstallRestarts(instance.getInstallRestarts());
      this.withInstallStartedTimestamp(instance.getInstallStartedTimestamp());
      this.withInstallVersion(instance.getInstallVersion());
      this.withInstalledTimestamp(instance.getInstalledTimestamp());
      this.withInstallerImage(instance.getInstallerImage());
      this.withPlatformStatus(instance.getPlatformStatus());
      this.withPowerState(instance.getPowerState());
      this.withProvisionRef(instance.getProvisionRef());
      this.withWebConsoleURL(instance.getWebConsoleURL());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeploymentStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeploymentStatus build() {
    ClusterDeploymentStatus buildable = new ClusterDeploymentStatus(fluent.getApiURL(),fluent.buildCertificateBundles(),fluent.getCliImage(),fluent.buildConditions(),fluent.getInstallRestarts(),fluent.getInstallStartedTimestamp(),fluent.getInstallVersion(),fluent.getInstalledTimestamp(),fluent.getInstallerImage(),fluent.buildPlatformStatus(),fluent.getPowerState(),fluent.buildProvisionRef(),fluent.getWebConsoleURL());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
